﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GoMallOracle.DAL
{
    using System.Data;
    using System.Data.OracleClient;
    using System.Data.SqlClient;
    using System.Media;

    using GoMallOracle.Models;

    using Utility;

    public class ProductTypeService
    {
        public static int Add(ProductType entity)
        {
            string sql = @"insert into producttype(id, name, up) values(seq_producttype.nextval,:v_name, :v_up)";
            OracleParameter[] parameters =
                {
                    new OracleParameter("v_name",entity.TypeName), 
                    new OracleParameter("v_up",entity.Up), 
                };
            return OracleHelper.ExecuteNonQuery(sql, parameters);
        }

        public static int DeleteById(int id)
        {
            string sql = @"delete producttype where id =:v_id";
            return OracleHelper.ExecuteNonQuery(sql, new OracleParameter("v_id", id));
        }

        public static int Update(ProductType entity)
        {
            string sql = @"update producttype set name =:v_name, up =:v_up where id =:v_id";
            OracleParameter[] parameters =
                {
                    new OracleParameter("v_id",entity.Id), 
                    new OracleParameter("v_name",entity.TypeName), 
                    new OracleParameter("v_up",entity.Up)
                };
            return OracleHelper.ExecuteNonQuery(sql, parameters);
        }

        public static List<ProductType> GetAll()
        {
            //这一段是用来测试的，没办法而已，*_*
            string strs = "";
            DataTable dt = GetProductSet();
            foreach (DataRow row in dt.Rows)
            {
                strs+=row[0] + "，" + row[1];
            }
            OracleDataReader odr = GetAllProducts();
            while (odr.Read())
            {
                strs+=odr.GetInt32(0) + "，" + odr.GetString(1);
            }
            System.IO.File.AppendAllText(@"c:\log.text",strs);
            string sql = "select id, name, up from producttype";

            List<ProductType> result = new List<ProductType>();
            OracleDataReader sdr = OracleHelper.ExecuteReader(sql);
            while (sdr.Read())
            {
                ProductType entity = new ProductType();
                //根据名称获得列号 Id Name Up
                entity.Id = sdr.GetInt32(sdr.GetOrdinal("id"));
                entity.TypeName = sdr.GetString(sdr.GetOrdinal("name"));
                entity.Up = sdr.GetInt32(sdr.GetOrdinal("up"));
                result.Add(entity);
            }
            sdr.Dispose();
            return result;
        }

        public static ProductType GetEntityById(int id)
        {
            string sql = "select id, name, up from producttype where id=:id";
            ProductType entity = null;
            OracleDataReader sdr = OracleHelper.ExecuteReader(sql, new OracleParameter("id", id));
            if (sdr.Read())
            {
                entity = new ProductType();
                entity.Id = sdr.GetInt32(0);
                entity.TypeName = sdr.GetString(1);
                entity.Up = sdr.GetInt32(2);
            }
            sdr.Dispose();
            return entity;
        }

        public static OracleDataReader GetAllProducts()
        {
            
            //定义连接对象
            OracleConnection conn = new OracleConnection("Data Source=orcl;Persist Security Info=True;User ID=t52;Unicode=True;Password=t52");
            //注意：包名.存储过程名的形式
            OracleCommand cmd = new OracleCommand("pkg_products.proc_GetAllProducts", conn);
            //设置命令类型为存储过程
            cmd.CommandType = CommandType.StoredProcedure;
            //定义参数，注意参数名必须与存储过程定义时一致，且类型为OracleType.Cursor
            OracleParameter cur_set = 
                new OracleParameter("cur_set", OracleType.Cursor);
            //设置参数为输出类型
            cur_set.Direction = ParameterDirection.Output;
            //添加参数
            cmd.Parameters.Add(cur_set);
            //打开连接
            conn.Open();
            //执行并返回OracleDataReader，注意使用后释放
            return cmd.ExecuteReader(CommandBehavior.CloseConnection);
        }

        public static DataTable GetProductSet()
        {
            using (OracleConnection conn = new OracleConnection(OracleHelper.connString))
            {
                using (OracleCommand cmd = 
                    new OracleCommand("pkg_products.proc_GetAllProducts", conn))
                {
                    cmd.CommandType = CommandType.StoredProcedure;
                    OracleParameter cur_set = 
                        new OracleParameter("cur_set", OracleType.Cursor);
                    cur_set.Direction = ParameterDirection.Output;
                    cmd.Parameters.Add(cur_set);
                    OracleDataAdapter adp = new OracleDataAdapter(cmd);
                    DataTable dataTable = new DataTable();
                    adp.Fill(dataTable);
                    return dataTable;
                }
            }
        }

    }
}
